Index: Ringtoets/Integration/src/Ringtoets.Integration.IO/Creators/AggregatedSerializableFailureMechanismCreator.cs
===================================================================
diff -u -rdaba41934fd3e36f126b88abdd88bc4266e08d33 -ra71b1ceb1838d97cabf3abad83710ce49f9dced9
--- Ringtoets/Integration/src/Ringtoets.Integration.IO/Creators/AggregatedSerializableFailureMechanismCreator.cs (.../AggregatedSerializableFailureMechanismCreator.cs) (revision daba41934fd3e36f126b88abdd88bc4266e08d33)
+++ Ringtoets/Integration/src/Ringtoets.Integration.IO/Creators/AggregatedSerializableFailureMechanismCreator.cs (.../AggregatedSerializableFailureMechanismCreator.cs) (revision a71b1ceb1838d97cabf3abad83710ce49f9dced9)
@@ -44,7 +44,7 @@
/// create an for.
/// An .
/// Thrown when any parameter is null.
- /// Thrown when the assembly result cannot be exported.
+ /// Thrown when the assembly result cannot be created.
/// Thrown when the
/// contains unsupported items in the failure mechanism section assembly results.
public static AggregatedSerializableFailureMechanism Create(IdentifierGenerator idGenerator,
@@ -92,7 +92,7 @@
/// create an for.
/// An .
/// Thrown when any parameter is null.
- /// Thrown when the assembly result cannot be exported.
+ /// Thrown when the assembly result cannot be created.
/// Thrown when the
/// contains unsupported items in the failure mechanism section assembly results.
public static AggregatedSerializableFailureMechanism Create(IdentifierGenerator idGenerator,
@@ -140,7 +140,7 @@
/// An aggregated failure mechanism section assembly result to
/// create an for.
/// An .
- /// Thrown when the assembly result cannot be exported.
+ /// Thrown when the assembly result cannot be created.
/// Thrown when an
/// cannot be created for .
private static AggregatedSerializableFailureMechanismSectionAssembly CreateFailureMechanismSectionAssembly(
Index: Ringtoets/Integration/src/Ringtoets.Integration.IO/Creators/SerializableAssemblyCreator.cs
===================================================================
diff -u -rdaba41934fd3e36f126b88abdd88bc4266e08d33 -ra71b1ceb1838d97cabf3abad83710ce49f9dced9
--- Ringtoets/Integration/src/Ringtoets.Integration.IO/Creators/SerializableAssemblyCreator.cs (.../SerializableAssemblyCreator.cs) (revision daba41934fd3e36f126b88abdd88bc4266e08d33)
+++ Ringtoets/Integration/src/Ringtoets.Integration.IO/Creators/SerializableAssemblyCreator.cs (.../SerializableAssemblyCreator.cs) (revision a71b1ceb1838d97cabf3abad83710ce49f9dced9)
@@ -1,4 +1,4 @@
-// Copyright (C) Stichting Deltares 2017. All rights reserved.
+// Copyright (C) Stichting Deltares 2017. All rights reserved.
//
// This file is part of Ringtoets.
//
@@ -46,7 +46,7 @@
/// A .
/// Thrown when
/// is null.
- /// Thrown when the assembly result cannot be exported.
+ /// Thrown when the assembly result cannot be created.
public static SerializableAssembly Create(ExportableAssessmentSection assessmentSection)
{
if (assessmentSection == null)
Index: Ringtoets/Integration/src/Ringtoets.Integration.IO/Exceptions/AssemblyCreatorException.cs
===================================================================
diff -u
--- Ringtoets/Integration/src/Ringtoets.Integration.IO/Exceptions/AssemblyCreatorException.cs (revision 0)
+++ Ringtoets/Integration/src/Ringtoets.Integration.IO/Exceptions/AssemblyCreatorException.cs (revision a71b1ceb1838d97cabf3abad83710ce49f9dced9)
@@ -0,0 +1,68 @@
+// Copyright (C) Stichting Deltares 2017. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
+using System.Runtime.Serialization;
+
+namespace Ringtoets.Integration.IO.Exceptions
+{
+ ///
+ /// Exception thrown when the assembly result cannot be created.
+ ///
+ [Serializable]
+ public class AssemblyCreatorException : Exception
+ {
+ ///
+ /// Initializes a new instance of the class.
+ ///
+ public AssemblyCreatorException() {}
+
+ ///
+ /// Initializes a new instance of the class
+ /// with a specified error message.
+ ///
+ /// The message that describes the error.
+ public AssemblyCreatorException(string message)
+ : base(message) {}
+
+ ///
+ /// Initializes a new instance of the class with a specified error message
+ /// and a reference to the inner exception that is the cause of this exception.
+ ///
+ /// The error message that explains the reason for the exception.
+ /// The exception that is the cause of the current exception,
+ /// or null if no inner exception is specified.
+ public AssemblyCreatorException(string message, Exception innerException) : base(message, innerException) {}
+
+ ///
+ /// Initializes a new instance of with
+ /// serialized data.
+ /// The that holds the serialized
+ /// object data about the exception being thrown.
+ /// The that contains contextual
+ /// information about the source or destination.
+ /// The parameter is
+ /// null.
+ /// The class name is null or
+ /// is zero (0).
+ protected AssemblyCreatorException(SerializationInfo info, StreamingContext context) : base(info, context) {}
+ }
+}
\ No newline at end of file
Fisheye: Tag a71b1ceb1838d97cabf3abad83710ce49f9dced9 refers to a dead (removed) revision in file `Ringtoets/Integration/src/Ringtoets.Integration.IO/Exceptions/AssemblyExportException.cs'.
Fisheye: No comparison available. Pass `N' to diff?
Index: Ringtoets/Integration/src/Ringtoets.Integration.IO/Exporters/AssemblyExporter.cs
===================================================================
diff -u -r4d38df69c95e64608027c29e7259bfaf4a068727 -ra71b1ceb1838d97cabf3abad83710ce49f9dced9
--- Ringtoets/Integration/src/Ringtoets.Integration.IO/Exporters/AssemblyExporter.cs (.../AssemblyExporter.cs) (revision 4d38df69c95e64608027c29e7259bfaf4a068727)
+++ Ringtoets/Integration/src/Ringtoets.Integration.IO/Exporters/AssemblyExporter.cs (.../AssemblyExporter.cs) (revision a71b1ceb1838d97cabf3abad83710ce49f9dced9)
@@ -79,7 +79,7 @@
SerializableAssemblyWriter.WriteAssembly(SerializableAssemblyCreator.Create(exportableAssessmentSection),
filePath);
}
- catch (AssemblyExportException)
+ catch (AssemblyCreatorException)
{
LogErrorMessage();
return false;
Index: Ringtoets/Integration/src/Ringtoets.Integration.IO/Ringtoets.Integration.IO.csproj
===================================================================
diff -u -r7a5ea209c1328bb33cca42166ccc046245cc04c4 -ra71b1ceb1838d97cabf3abad83710ce49f9dced9
--- Ringtoets/Integration/src/Ringtoets.Integration.IO/Ringtoets.Integration.IO.csproj (.../Ringtoets.Integration.IO.csproj) (revision 7a5ea209c1328bb33cca42166ccc046245cc04c4)
+++ Ringtoets/Integration/src/Ringtoets.Integration.IO/Ringtoets.Integration.IO.csproj (.../Ringtoets.Integration.IO.csproj) (revision a71b1ceb1838d97cabf3abad83710ce49f9dced9)
@@ -57,7 +57,7 @@
-
+
Index: Ringtoets/Integration/test/Ringtoets.Integration.IO.Test/Creators/AggregatedSerializableFailureMechanismSectionAssemblyCreatorTest.cs
===================================================================
diff -u -rdaba41934fd3e36f126b88abdd88bc4266e08d33 -ra71b1ceb1838d97cabf3abad83710ce49f9dced9
--- Ringtoets/Integration/test/Ringtoets.Integration.IO.Test/Creators/AggregatedSerializableFailureMechanismSectionAssemblyCreatorTest.cs (.../AggregatedSerializableFailureMechanismSectionAssemblyCreatorTest.cs) (revision daba41934fd3e36f126b88abdd88bc4266e08d33)
+++ Ringtoets/Integration/test/Ringtoets.Integration.IO.Test/Creators/AggregatedSerializableFailureMechanismSectionAssemblyCreatorTest.cs (.../AggregatedSerializableFailureMechanismSectionAssemblyCreatorTest.cs) (revision a71b1ceb1838d97cabf3abad83710ce49f9dced9)
@@ -139,8 +139,8 @@
sectionResult);
// Assert
- var exception = Assert.Throws(call);
- Assert.AreEqual("The assembly result is invalid and cannot be exported.", exception.Message);
+ var exception = Assert.Throws(call);
+ Assert.AreEqual("The assembly result is invalid and cannot be created.", exception.Message);
}
[Test]
@@ -370,8 +370,8 @@
sectionResult);
// Assert
- var exception = Assert.Throws(call);
- Assert.AreEqual("The assembly result is invalid and cannot be exported.", exception.Message);
+ var exception = Assert.Throws(call);
+ Assert.AreEqual("The assembly result is invalid and cannot be created.", exception.Message);
}
[Test]
@@ -597,8 +597,8 @@
sectionResult);
// Assert
- var exception = Assert.Throws(call);
- Assert.AreEqual("The assembly result is invalid and cannot be exported.", exception.Message);
+ var exception = Assert.Throws(call);
+ Assert.AreEqual("The assembly result is invalid and cannot be created.", exception.Message);
}
[Test]
Index: Ringtoets/Integration/test/Ringtoets.Integration.IO.Test/Exceptions/AssemblyCreatorExceptionTest.cs
===================================================================
diff -u
--- Ringtoets/Integration/test/Ringtoets.Integration.IO.Test/Exceptions/AssemblyCreatorExceptionTest.cs (revision 0)
+++ Ringtoets/Integration/test/Ringtoets.Integration.IO.Test/Exceptions/AssemblyCreatorExceptionTest.cs (revision a71b1ceb1838d97cabf3abad83710ce49f9dced9)
@@ -0,0 +1,32 @@
+// Copyright (C) Stichting Deltares 2017. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
+using Core.Common.TestUtil;
+using NUnit.Framework;
+using Ringtoets.Integration.IO.Exceptions;
+
+namespace Ringtoets.Integration.IO.Test.Exceptions
+{
+ [TestFixture]
+ public class AssemblyCreatorExceptionTest :
+ CustomExceptionDesignGuidelinesTestFixture {}
+}
\ No newline at end of file
Fisheye: Tag a71b1ceb1838d97cabf3abad83710ce49f9dced9 refers to a dead (removed) revision in file `Ringtoets/Integration/test/Ringtoets.Integration.IO.Test/Exceptions/AssemblyExportExceptionTest.cs'.
Fisheye: No comparison available. Pass `N' to diff?
Index: Ringtoets/Integration/test/Ringtoets.Integration.IO.Test/Exporters/AssemblyExporterTest.cs
===================================================================
diff -u -ra46f237c3c174d916c321c52e8d0dea4f620696c -ra71b1ceb1838d97cabf3abad83710ce49f9dced9
--- Ringtoets/Integration/test/Ringtoets.Integration.IO.Test/Exporters/AssemblyExporterTest.cs (.../AssemblyExporterTest.cs) (revision a46f237c3c174d916c321c52e8d0dea4f620696c)
+++ Ringtoets/Integration/test/Ringtoets.Integration.IO.Test/Exporters/AssemblyExporterTest.cs (.../AssemblyExporterTest.cs) (revision a71b1ceb1838d97cabf3abad83710ce49f9dced9)
@@ -138,7 +138,7 @@
}
[Test]
- public void Export_CombinedFailureMechanismSectionAssemblyResultNone_LogsErrorAndReturnsFalse()
+ public void Export_AssemblyCreateorExceptionThrown_LogsErrorAndReturnsFalse()
{
// Setup
string filePath = TestHelper.GetScratchPadPath(nameof(Export_InvalidAssessmentSectionCategoryGroupResults_LogsErrorAndReturnsFalse));
Index: Ringtoets/Integration/test/Ringtoets.Integration.IO.Test/Ringtoets.Integration.IO.Test.csproj
===================================================================
diff -u -r7a5ea209c1328bb33cca42166ccc046245cc04c4 -ra71b1ceb1838d97cabf3abad83710ce49f9dced9
--- Ringtoets/Integration/test/Ringtoets.Integration.IO.Test/Ringtoets.Integration.IO.Test.csproj (.../Ringtoets.Integration.IO.Test.csproj) (revision 7a5ea209c1328bb33cca42166ccc046245cc04c4)
+++ Ringtoets/Integration/test/Ringtoets.Integration.IO.Test/Ringtoets.Integration.IO.Test.csproj (.../Ringtoets.Integration.IO.Test.csproj) (revision a71b1ceb1838d97cabf3abad83710ce49f9dced9)
@@ -59,7 +59,7 @@
-
+
Index: Ringtoets/Integration/src/Ringtoets.Integration.IO/Creators/AggregatedSerializableFailureMechanismSectionAssemblyCreator.cs
===================================================================
diff -u -rfbce8d11e6be9fc7a46c983ec266001a12e9f4ed -ra71b1ceb1838d97cabf3abad83710ce49f9dced9
--- Ringtoets/Integration/src/Ringtoets.Integration.IO/Creators/AggregatedSerializableFailureMechanismSectionAssemblyCreator.cs (.../AggregatedSerializableFailureMechanismSectionAssemblyCreator.cs) (revision fbce8d11e6be9fc7a46c983ec266001a12e9f4ed)
+++ Ringtoets/Integration/src/Ringtoets.Integration.IO/Creators/AggregatedSerializableFailureMechanismSectionAssemblyCreator.cs (.../AggregatedSerializableFailureMechanismSectionAssemblyCreator.cs) (revision a71b1ceb1838d97cabf3abad83710ce49f9dced9)
@@ -49,7 +49,7 @@
/// for.
/// An .
/// Thrown when any parameter is null.
/// Thrown when the assembly result cannot be exported.
public static AggregatedSerializableFailureMechanismSectionAssembly Create(IdentifierGenerator idGenerator,
SerializableFailureMechanismSectionCollection serializableCollection,
SerializableFailureMechanism serializableFailureMechanism,
@@ -102,7 +102,7 @@
/// for.
/// An .
/// Thrown when any parameter is null.
/// Thrown when the assembly result cannot be exported.
public static AggregatedSerializableFailureMechanismSectionAssembly Create(IdentifierGenerator idGenerator,
SerializableFailureMechanismSectionCollection serializableCollection,
SerializableFailureMechanism serializableFailureMechanism,
@@ -155,7 +155,7 @@
/// for.
/// An .
/// Thrown when any parameter is null.
/// Thrown when the assembly result cannot be exported.
public static AggregatedSerializableFailureMechanismSectionAssembly Create(IdentifierGenerator idGenerator,
SerializableFailureMechanismSectionCollection serializableCollection,
SerializableFailureMechanism serializableFailureMechanism,
@@ -201,13 +201,13 @@
/// Validates whether an is valid to export.
///
/// The to validate.
- /// Thrown when
- /// is invalid to export.
+ /// Thrown when
+ /// is invalid to create.
private static void ValidateAssemblyResult(ExportableSectionAssemblyResult result)
{
if (result.AssemblyCategory == FailureMechanismSectionAssemblyCategoryGroup.None)
{
- throw new AssemblyExportException(@"The assembly result is invalid and cannot be exported.");
+ throw new AssemblyCreatorException(@"The assembly result is invalid and cannot be created.");
}
}
@@ -49,7 +49,7 @@
/// An .
/// Thrown when any parameter is null.
- /// Thrown when the assembly result cannot be exported.
+ /// Thrown when the assembly result cannot be created.
public static AggregatedSerializableFailureMechanismSectionAssembly Create(IdentifierGenerator idGenerator,
SerializableFailureMechanismSectionCollection serializableCollection,
@@ -102,7 +102,7 @@
/// An .
/// Thrown when any parameter is null.
- /// Thrown when the assembly result cannot be exported.
+ /// Thrown when the assembly result cannot be created.
public static AggregatedSerializableFailureMechanismSectionAssembly Create(IdentifierGenerator idGenerator,
SerializableFailureMechanismSectionCollection serializableCollection,
@@ -155,7 +155,7 @@
/// An .
/// Thrown when any parameter is null.
- /// Thrown when the assembly result cannot be exported.
+ /// Thrown when the assembly result cannot be created.
public static AggregatedSerializableFailureMechanismSectionAssembly Create(IdentifierGenerator idGenerator,
SerializableFailureMechanismSectionCollection serializableCollection,